pub enum ConflictResolutionStrategy {
DenyOverrides,
AllowOverrides,
PriorityFirstMatch,
MostSpecificWins,
}Expand description
Conflict resolution strategy when multiple policy rules produce different decisions.
Variants
DenyOverrides
Any deny decision overrides allows.
AllowOverrides
Any allow decision overrides denies.
PriorityFirstMatch
The candidate with the highest priority wins.
MostSpecificWins
The most specific scope wins, with priority as tiebreaker.